@@ -1,4 +1,4 @@
-from typing import Iterable, List, Union
+from collections.abc import Iterable
 
 
 class Unspecified:
@@ -9,10 +9,10 @@ _UnspecifiedAllowList = Unspecified()
 _UnspecifiedSourceList = Unspecified()
 
 
-Directives = List[str]
-Sources = List[str]
-AllowList = Union[Directives, Unspecified]
-SourceList = Union[Sources, Unspecified]
+Directives = list[str]
+Sources = list[str]
+AllowList = Directives | Unspecified
+SourceList = Sources | Unspecified
 
 raw_directives = {'*', 'src', 'self'}
 
@@ -21,7 +21,7 @@ def _flatten_directives(ds: Directives) -> str:
   return ' '.join(d if d in raw_directives else f'"{d}"' for d in ds)
 
 
-def _handle_directive_allowlist(feature: AllowList, feature_name: str, result: List[str]):
+def _handle_directive_allowlist(feature: AllowList, feature_name: str, result: list[str]):
   if isinstance(feature, Iterable):
     result.append(f'{feature_name}=({_flatten_directives(feature)})')
 
@@ -30,7 +30,7 @@ def permissions_policy(
   autoplay: AllowList = _UnspecifiedAllowList,
   fullscreen: AllowList = _UnspecifiedAllowList,
 ) -> str:
-  result = []
+  result: list[str] = []
   _handle_directive_allowlist(autoplay, 'autoplay', result)
   _handle_directive_allowlist(fullscreen, 'fullscreen', result)
   return ', '.join(result)
@@ -63,7 +63,7 @@ def _flatten_sources(ss: Sources) -> str:
   return ' '.join(f"'{s}'" if _should_quote(s) else s for s in ss)
 
 
-def _handle_sourcelist(sources: SourceList, policy_name: str, result: List[str]) -> None:
+def _handle_sourcelist(sources: SourceList, policy_name: str, result: list[str]) -> None:
   if isinstance(sources, Iterable):
     result.append(f'{policy_name} {_flatten_sources(sources)}')
 
@@ -78,7 +78,7 @@ def content_security_policy(
   worker_src: SourceList = _UnspecifiedSourceList,
   object_src: SourceList = _UnspecifiedSourceList,
 ) -> str:
-  result = []
+  result: list[str] = []
   _handle_sourcelist(default_src, 'default-src', result)
   _handle_sourcelist(font_src, 'font-src', result)
   _handle_sourcelist(img_src, 'img-src', result)
