@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from functools import partial
-from typing import Any, Awaitable, Callable, TypeVar
+from typing import Any, Awaitable, Callable, TypeAliasType, TypeVar
 
 import humps
 from aiohttp import web
@@ -31,13 +31,13 @@ class WSRouteDetails[ErrorType](BaseRouteDetails[ErrorType]):
 
 def get_ws_route_details(func: Callable[..., Any]) -> WSRouteDetails[Any]:
   return WSRouteDetails(
-    name=func._alxhttp_route_name,
-    match_info=func._alxhttp_match_info,
-    query=func._alxhttp_query,
-    client_msg=func._alxhttp_client_msg,
-    server_msg=func._alxhttp_server_msg,
-    ts_name=func._alxhttp_ts_name,
-    errors=func._alxhttp_errors or [],
+    name=func._alxhttp_route_name,  # pyright: ignore[reportFunctionMemberAccess]
+    match_info=func._alxhttp_match_info,  # pyright: ignore[reportFunctionMemberAccess]
+    query=func._alxhttp_query,  # pyright: ignore[reportFunctionMemberAccess]
+    client_msg=func._alxhttp_client_msg,  # pyright: ignore[reportFunctionMemberAccess]
+    server_msg=func._alxhttp_server_msg,  # pyright: ignore[reportFunctionMemberAccess]
+    ts_name=func._alxhttp_ts_name,  # pyright: ignore[reportFunctionMemberAccess]
+    errors=func._alxhttp_errors or [],  # pyright: ignore[reportFunctionMemberAccess]
   )
 
 
@@ -47,8 +47,8 @@ class EmptyMsg(BaseModel):
 
 def ws_route(
   name: str,
-  client_msg: type[ClientMsgType],
-  server_msg: type[ServerMsgType],
+  client_msg: type[ClientMsgType] | TypeAliasType,
+  server_msg: type[ServerMsgType] | TypeAliasType,
   ts_name: str | None = None,
   match_info: type[MatchInfoType] = Empty,
   query: type[QueryType] = Empty,
