@@ -3,9 +3,11 @@ from collections import defaultdict
 from collections.abc import Generator
 from dataclasses import dataclass, field
 from datetime import datetime
-from typing import Any, get_type_hints
+from typing import Any, TypeAliasType, get_type_hints
 
+import pydantic
 from pydantic import BaseModel, HttpUrl
+from pydantic.types import AwareDatetime
 
 from alxhttp.pydantic.route import RouteDetails
 from alxhttp.typescript.basic_syntax import braces
@@ -16,6 +18,7 @@ from alxhttp.typescript.type_checks import (
   is_alias,
   is_annotated,
   is_class_var,
+  is_class_var_or_annotated_class_var,
   is_dict,
   is_generic_type,
   is_list,
@@ -45,45 +48,68 @@ class PydanticErrorResp(BaseModel):
   errors: list[PydanticError]
 
 
-def model_to_type(name: str, model) -> ObjectType:
+def should_skip_field(field_name: str, field_type: type | TypeAliasType) -> bool:
+  if is_class_var_or_annotated_class_var(field_type):
+    return True
+  elif field_type == pydantic.ConfigDict:
+    return True
+  elif field_name.startswith('_'):
+    return True
+  elif is_annotated(field_type) and typing.get_args(field_type)[0] == pydantic.ConfigDict:
+    return True
+  return False
+
+
+def model_to_type(name: str, model: Any) -> ObjectType:
   model_fields = get_type_hints(model, include_extras=True)
-  fields = []
+  fields: list[ObjectTypeField] = []
   for field_name, field_type in model_fields.items():
-    td = TypeDecl(field_type)
-    if is_class_var(field_type):
+    if should_skip_field(field_name, field_type):
       continue
+    td = TypeDecl(field_type, self_type=model)
     fields.append(ObjectTypeField(field_name, td, None))
 
   return ObjectType(name, fields)
 
 
-def nullable_union_of_toplevel_fields(name: str, models) -> ObjectType:
+def _get_arg_list(t: type | TypeAliasType) -> list[type | TypeAliasType]:
+  args = typing.get_args(t)
+  return list(args)
+
+
+def nullable_union_of_toplevel_fields(name: str, models: list[Any]) -> ObjectType:
   fields: list[ObjectTypeField] = []
   for model in models:
     model_fields = get_type_hints(model, include_extras=True)
 
     for field_name, field_type in model_fields.items():
+      if should_skip_field(field_name, field_type):
+        continue
       if not is_optional(field_type):
         field_type = field_type | None | TSUndefined
-      fields.append(ObjectTypeField(field_name, TypeDecl(field_type), None))
+      fields.append(ObjectTypeField(field_name, TypeDecl(field_type, self_type=model), None))
 
   return ObjectType(name, fields, export=False)
 
 
-def jsdoc_of_toplevel_fields(models) -> list[str]:
+def jsdoc_of_toplevel_fields(models: list[Any]) -> list[str]:
   fields: list[ObjectTypeField] = []
   for model in models:
     model_fields = get_type_hints(model, include_extras=True)
 
     for field_name, field_type in model_fields.items():
-      fields.append(ObjectTypeField(field_name, TypeDecl(field_type), None))
+      if should_skip_field(field_name, field_type):
+        continue
+      fields.append(ObjectTypeField(field_name, TypeDecl(field_type, self_type=model), None))
 
   return [f'@param {{{f.decl}}} {f.name}' for f in fields]
 
 
-def extract_enum_references(enum: dict[str, set[str]], model) -> None:
+def extract_enum_references(enum: dict[str, set[str]], model: Any) -> None:
   model_fields = get_type_hints(model, include_extras=True)
-  for _, field_type in model_fields.items():
+  for field_name, field_type in model_fields.items():
+    if should_skip_field(field_name, field_type):
+      continue
     if is_annotated(field_type):
       targs = typing.get_args(field_type)
       if isinstance(targs[1], TSEnum):
@@ -94,7 +120,7 @@ def gen_wire_func(name: str, ret_type: str, object_init: ObjectInit):
   return f'export function {name}(root: any): {ret_type} {{ return {object_init} }};\n'
 
 
-def recurse_model_types(t: type, seen: set[type] | None = None) -> Generator[type, None, None]:
+def recurse_model_types(t: type | TypeAliasType, seen: set[type | TypeAliasType] | None = None) -> Generator[type | TypeAliasType, None, None]:
   if seen is None:
     seen = set()
 
@@ -102,7 +128,7 @@ def recurse_model_types(t: type, seen: set[type] | None = None) -> Generator[typ
     return
   seen.add(t)
 
-  if is_class_var(t):
+  if should_skip_field('', t):
     return
 
   if is_alias(t):
@@ -117,16 +143,27 @@ def recurse_model_types(t: type, seen: set[type] | None = None) -> Generator[typ
     yield t
 
     model_fields = get_type_hints(t)
-    for _, field_type in model_fields.items():
+    for field_name, field_type in model_fields.items():
+      if should_skip_field(field_name, field_type):
+        continue
       yield from recurse_model_types(field_type, seen)
 
 
-def _discrimination_expr(src_name: str, type_args: list[type]) -> str:
+def _first_real_field(subtype: type | TypeAliasType) -> tuple[str, type | TypeAliasType]:
+  model_fields = get_type_hints(subtype)
+  for first_name, field_type in model_fields.items():
+    if should_skip_field(first_name, field_type):
+      continue
+    return first_name, field_type
+  assert False
+
+
+def _discrimination_expr(src_name: str, type_args: list[type | TypeAliasType]) -> str:
   discrimination_expr = ''
   first_first_name = None
   finished = False
   for n, subtype in enumerate(type_args):
-    first_name, first_field_type = list(get_type_hints(subtype).items())[0]
+    first_name, first_field_type = _first_real_field(subtype)
     if not first_first_name:
       first_first_name = first_name
     assert first_name == first_first_name  # simplifying assumption: all subtypes will have a common first literal key
@@ -147,21 +184,21 @@ def _discrimination_expr(src_name: str, type_args: list[type]) -> str:
 
 @dataclass
 class TypeIndex:
-  py_to_ts: dict[type, ObjectType] = field(default_factory=dict)
-  ts_to_py: dict[str, type] = field(default_factory=dict)
+  py_to_ts: dict[type | TypeAliasType, ObjectType] = field(default_factory=dict)
+  ts_to_py: dict[str, type | TypeAliasType] = field(default_factory=dict)
 
-  py_to_wire_func: dict[type, str] = field(default_factory=dict)
-  py_to_wire_func_name: dict[type, str] = field(default_factory=dict)
+  py_to_wire_func: dict[type | TypeAliasType, str] = field(default_factory=dict)
+  py_to_wire_func_name: dict[type | TypeAliasType, str] = field(default_factory=dict)
 
-  serialize_wire_func: dict[type, str] = field(default_factory=dict)
-  serialize_wire_func_name: dict[type, str] = field(default_factory=dict)
+  serialize_wire_func: dict[type | TypeAliasType, str] = field(default_factory=dict)
+  serialize_wire_func_name: dict[type | TypeAliasType, str] = field(default_factory=dict)
 
-  py_to_ts_union: dict[type, UnionType] = field(default_factory=dict)
+  py_to_ts_union: dict[type | TypeAliasType, UnionType] = field(default_factory=dict)
 
-  enum_refs: defaultdict[str, set[str]] = defaultdict(set)
+  enum_refs: defaultdict[str, set[str]] = field(default_factory=lambda: defaultdict(set))
 
   def gen_enum_defs(self) -> str:
-    tdefs = []
+    tdefs: list[str] = []
     for ename, evals in self.enum_refs.items():
       tdefs.append(f'enum {ename} {braces([f"{ev} = '{ev}'" for ev in sorted(evals)], sep=",")};')
     return '\n\n'.join(tdefs) + '\n\n'
@@ -173,14 +210,14 @@ class TypeIndex:
 
   def recurse_model(self, mt: type, init_from_wire: bool = True, init_to_wire: bool = True) -> None:
     for m in recurse_model_types(mt):
-      if is_alias(m) and is_union_of_models(m.__value__):
+      if should_skip_field('', m):
+        continue
+      elif is_alias(m) and is_union_of_models(m.__value__):
         type_name = str(m)
         union_type = m.__value__
         self.py_to_ts_union[union_type] = UnionType(type_name, members=[extract_class(c) for c in typing.get_args(union_type)], export=True)
         if init_from_wire:
           self.init_discriminated_union_from_wire(union_type)
-      elif is_class_var(m):
-        continue  # ignore these
       else:
         ts_name = extract_class(m)
         t = model_to_type(ts_name, m)
@@ -193,40 +230,40 @@ class TypeIndex:
         if init_to_wire:
           self.init_to_wire(m)
 
-  def _gen_init_field_assignment(self, type: type, src_name: str = 'root', depth: int = 0) -> str | None:
+  def _gen_init_field_assignment(self, type: type | TypeAliasType, src_name: str = 'root', depth: int = 0, self_type: type | TypeAliasType | None = None) -> str | None:
     depth += 1
 
     kn = f'k{depth}'
     vn = f'v{depth}'
 
-    type_args = typing.get_args(type)
+    type_args = _get_arg_list(type)
 
-    if type in SAFE_PRIMITIVE_TYPES:
+    if is_annotated(type):
+      return self._gen_init_field_assignment(type_args[0], src_name, depth, self_type)
+    elif type in SAFE_PRIMITIVE_TYPES:
       return src_name
     elif type == HttpUrl:
       return src_name
     elif is_literal(type):
       return src_name
-    elif type == datetime:
+    elif type == datetime or type == AwareDatetime:  # pyright: ignore[reportUnnecessaryComparison]
       return f'new Date({src_name} * 1000)'
     elif type == Any:
       return src_name
     elif is_class_var(type):
       return None
-    elif is_annotated(type):
-      return self._gen_init_field_assignment(type_args[0], src_name, depth)
     elif is_alias(type):
-      return self._gen_init_field_assignment(type.__value__, src_name, depth)
+      return self._gen_init_field_assignment(type.__value__, src_name, depth, self_type)
     elif is_list(type) or is_tuple(type):
       if is_safe_primitive_type_or_union(type_args[0]):
         # Small optimization
         return src_name
 
-      return f'{src_name}.map(({vn}: {pytype_to_tstype(type_args[0])}) => {{ return {self._gen_init_field_assignment(type_args[0], vn, depth)} }})'
+      return f'{src_name}.map(({vn}: {pytype_to_tstype(type_args[0], self_type=self_type)}) => {{ return {self._gen_init_field_assignment(type_args[0], vn, depth, self_type)} }})'
     elif is_union_of_safe_primitive_types_or_none(type):
       return src_name
     elif is_optional(type):
-      sub = self._gen_init_field_assignment(type_args[0], src_name, depth)
+      sub = self._gen_init_field_assignment(type_args[0], src_name, depth, self_type)
       if sub is None:
         return None
       return f'({src_name} === null) ? null : ' + sub
@@ -239,13 +276,18 @@ class TypeIndex:
       assert is_type_or_annotated_type(type_args[0], str)
       ktype = pytype_to_tstype(type_args[0])
       vtype = pytype_to_tstype(type_args[1])
-      return f'Object.fromEntries(Object.entries({src_name} as Record<{ktype}, {vtype}>).map(([{kn}, {vn}]) => {{ return [{kn}, {self._gen_init_field_assignment(type_args[1], vn, depth)}] }} ))'
+      return (
+        f'Object.fromEntries(Object.entries({src_name} as Record<{ktype}, {vtype}>).map(([{kn}, {vn}]) => {{ return [{kn}, {self._gen_init_field_assignment(type_args[1], vn, depth, self_type)}] }} ))'
+      )
     elif is_model_type(type):
       return f'get{pytype_to_tstype(type)}FromWire({src_name})'
+    elif type == typing.Self:
+      assert self_type is not None
+      return self._gen_init_field_assignment(self_type, src_name, depth, self_type)
     else:
       raise ValueError
 
-  def _gen_uninit_field_assignment(self, type: type, src_name: str = 'root', depth: int = 0) -> str | None:
+  def _gen_uninit_field_assignment(self, type: type | TypeAliasType, src_name: str = 'root', depth: int = 0, self_type: type | TypeAliasType | None = None) -> str | None:
     depth += 1
 
     kn = f'k{depth}'
@@ -253,27 +295,30 @@ class TypeIndex:
 
     type_args = typing.get_args(type)
 
-    if type in SAFE_PRIMITIVE_TYPES:
+    if is_annotated(type):
+      return self._gen_uninit_field_assignment(type_args[0], src_name, depth, self_type)
+    elif type in SAFE_PRIMITIVE_TYPES:
       return src_name
     elif is_literal(type):
       return src_name
-    elif type == datetime:
+    elif type == datetime or type == AwareDatetime:  # pyright: ignore[reportUnnecessaryComparison]
       return f'{src_name}.getTime()'
     elif type == Any:
       return src_name
-    elif is_class_var(type):
+    elif should_skip_field('', type):
       return None
-    elif is_annotated(type):
-      return self._gen_uninit_field_assignment(type_args[0], src_name, depth)
+    elif type == typing.Self:
+      assert self_type is not None
+      return self._gen_uninit_field_assignment(self_type, src_name, depth, self_type)
     elif is_alias(type):
-      return self._gen_uninit_field_assignment(type.__value__, src_name, depth)
+      return self._gen_uninit_field_assignment(type.__value__, src_name, depth, self_type)
     elif is_list(type) or is_tuple(type):
       # TODO: ignoring tuple types
-      return f'{src_name}.map(({vn}: {pytype_to_tstype(type_args[0])}) => {{ return {self._gen_uninit_field_assignment(type_args[0], vn, depth)} }})'
+      return f'{src_name}.map(({vn}: {pytype_to_tstype(type_args[0], self_type=self_type)}) => {{ return {self._gen_uninit_field_assignment(type_args[0], vn, depth, self_type)} }})'
     elif is_union_of_safe_primitive_types_or_none(type):
       return src_name
     elif is_optional(type):
-      sub = self._gen_uninit_field_assignment(type_args[0], src_name, depth)
+      sub = self._gen_uninit_field_assignment(type_args[0], src_name, depth, self_type)
       if sub is None:
         return None
       return f'({src_name} === null) ? null : ' + sub
@@ -291,10 +336,10 @@ class TypeIndex:
           if isinstance(literal_value, str):
             literal_value = f"'{literal_value}'"
 
-          discrimination_expr += f'({src_name}.{first_name} === {literal_value}) ? convert{pytype_to_tstype(subtype)}ToWire({src_name}) : '
+          discrimination_expr += f'({src_name}.{first_name} === {literal_value}) ? convert{pytype_to_tstype(subtype, self_type=self_type)}ToWire({src_name}) : '
         elif n == len(type_args) - 1:
           finished = True
-          discrimination_expr += f'convert{pytype_to_tstype(subtype)}ToWire({src_name})'
+          discrimination_expr += f'convert{pytype_to_tstype(subtype, self_type=self_type)}ToWire({src_name})'
 
       if not finished:
         discrimination_expr += ' unreachable()'
@@ -306,19 +351,19 @@ class TypeIndex:
       assert is_type_or_annotated_type(type_args[0], str)
       ktype = pytype_to_tstype(type_args[0])
       vtype = pytype_to_tstype(type_args[1])
-      sub = self._gen_uninit_field_assignment(type_args[1], vn, depth)
+      sub = self._gen_uninit_field_assignment(type_args[1], vn, depth, self_type)
       if sub is None:
         return None
       return f'Object.fromEntries(Object.entries({src_name} as Record<{ktype}, {vtype}>).map(([{kn}, {vn}]) => {{ return [{kn}, {sub}] }} ))'
 
     elif is_model_type(type):
-      return f'convert{pytype_to_tstype(type)}ToWire({src_name})'
+      return f'convert{pytype_to_tstype(type, self_type=self_type)}ToWire({src_name})'
     else:
       raise ValueError
 
   def init_discriminated_union_from_wire(self, py_type: type, wire_arg: str = 'root') -> str:
     ts_type = self.py_to_ts_union[py_type]
-    de = _discrimination_expr(wire_arg, typing.get_args(py_type))
+    de = _discrimination_expr(wire_arg, _get_arg_list(py_type))
 
     wire_func_name = f'get{ts_type.name}FromWire'
     wire_func = f'export function {wire_func_name}(root: any): {ts_type.name} {{ return {de} }};\n'
@@ -328,7 +373,7 @@ class TypeIndex:
 
     return wire_func
 
-  def init_from_wire(self, py_type: type, wire_arg: str = 'root') -> str:
+  def init_from_wire(self, py_type: type | TypeAliasType, wire_arg: str = 'root') -> str:
     """
     Inits a new JS object based on one that came via json over the wire. Allows
     us to do things like turn float timestamps into js Date objects.
@@ -336,7 +381,8 @@ class TypeIndex:
     ts_type = self.py_to_ts[py_type]
     field_assignments: list[ObjectInitField] = []
     for tsfield in ts_type.fields:
-      field_type = self._gen_init_field_assignment(tsfield.decl.decl, f'{wire_arg}.{tsfield.name}')
+      assert not isinstance(tsfield.decl.decl, str)
+      field_type = self._gen_init_field_assignment(tsfield.decl.decl, f'{wire_arg}.{tsfield.name}', depth=0, self_type=py_type)
       if field_type is None:
         continue
       field_assignments.append(
@@ -355,7 +401,7 @@ class TypeIndex:
 
     return wire_func
 
-  def init_to_wire(self, py_type: type, wire_arg: str = 'root') -> str:
+  def init_to_wire(self, py_type: type | TypeAliasType, wire_arg: str = 'root') -> str:
     """
     Inits a new JS object to be sent over the wire. Allows
     us to do things like turn js Date objects into float timestamps.
@@ -363,10 +409,11 @@ class TypeIndex:
     ts_type = self.py_to_ts[py_type]
     field_assignments: list[ObjectInitField] = []
     for tsfield in ts_type.fields:
+      assert not isinstance(tsfield.decl.decl, str)
       field_assignments.append(
         ObjectInitField(
           tsfield.name,
-          self._gen_uninit_field_assignment(tsfield.decl.decl, f'{wire_arg}.{tsfield.name}'),
+          self._gen_uninit_field_assignment(tsfield.decl.decl, f'{wire_arg}.{tsfield.name}', self_type=py_type),
         )
       )
 
